==> nextcloud-25.0.8.tgz: nextcloud/apps/photos/l10n/sl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Javna povezava",
    "Photos" : "Fotografije",
    "Your memories under your control" : "Spomini pod vašim nadzorom",
    "All media" : "Vsi viri",
    "Videos" : "Video posnetki",
    "Albums" : "Albumi",
    "Collaborative albums" : "Sodelovalni albumi",
    "People" : "Ljudje",
    "Folders" : "Mape",
    "Favorites" : "Priljubljene",
    "On this day" : "Na današnji dan",
    "Shared with you" : "V souporabi z vami",
    "Tags" : "Oznake",
    "Places" : "Mesta",
    "Map" : "Zemljevid",
    "Photos settings" : "Nastavitve fotografij",
    "Mark selection as favorite" : "Označi izbor kot priljubljene",
    "Add selection to favorites" : "Dodaj izbor med priljubljene",
    "Remove selection from favorites" : "Odstrani izbor iz priljubljenih",
    "Name of the album" : "Ime albuma",
    "Location of the album" : "Mesto albuma",
    "Go back to the previous view." : "Vrni na predhodni pogled.",
    "Back" : "Nazaj",
    "Go to the add collaborators view." : "Skoči na pogled dodajanja sodelujočih.",
    "Add collaborators" : "Dodaj sodelujoče",
    "Save." : "Shrani.",
    "Create the album." : "Ustvari album",
    "Save" : "Shrani",
    "Create album" : "Ustvari album",
    "Back to the new album form." : "Nazaj na pogled obrazca novega albuma.",
    "Add to Album" : "Dodaj v album",
    "Add selection to album {albumName}" : "Dodaj izbor v album {albumName}",
    "Shared by" : "Souporabo omogoča",
    "Create a new album." : "Ustvari nov album.",
    "Create new album" : "Ustvari nov album.",
    "New album" : "Nov album",
    "_%n item_::_%n photos and videos_" : ["%n slika ali videoposnetkek","%n sliki ali videoposnetka","%n slike ali videoposnetki","%n slik in videoposnetkov"],
    "Add people or groups who can edit your album" : "Dodaj osebe in skupine, ki lahko urejajo album",
    "Search people or groups" : "Iskanje oseb in skupin",
    "No recommendations. Start typing." : "Ni priporočil; začnite z vpisovanjem",
    "Group" : "Skupina",
    "Remove {collaboratorLabel} from the collaborators list" : "Odstrani {collaboratorLabel} s seznama sodelujočih",
    "Copy the public link" : "Kopiraj javno povezavo",
    "Public link copied!" : "Povezava je kopirana!",
    "Copy public link" : "Kopiraj javno povezavo",
    "Delete the public link" : "Izbriši javno povezavo",
    "Share via public link" : "V souporabi z javno povezavo",
    "Failed to fetch collaborators list." : "Pridobivanje seznama sodelovanja je spodletelo.",
    "Failed to update album." : "Posodabljanje albuma je spodletelo.",
    "This collection does not exist" : "Zbirka ne obstaja.",
    "An error occurred" : "Prišlo je do napake.",
    "_%n photos_::_%n photos_" : ["%n fotografija","%n fotografiji","%n fotografije","%n fotografij"],
    "Select image {imageName}" : "Izbor slike {imageName}",
    "The file is in the favorites" : "Datoteka je med priljubljenimi",
    "Open the full size \"{name}\" image" : "Odpri sliko »{name}« v polni velikosti",
    "There are no photos or videos yet!" : "Ni še naloženih fotografij in posnetkov!",
    "Add to {destination}" : "Dodaj k {cilju}",
    "Open the \"{name}\" sub-directory" : "Odpri podmapo »{name}«",
    "Back to {folder}" : "Nazaj v mapo {folder}",
    "Share this folder" : "Omogoči souporabo mape",
    "_{years} year ago_::_{years} years ago_" : ["pred {years} letom","pred {years} letoma","pred {years} leti","pred {years} leti"],
    "Enable squared photos view" : "Omogoči kvadratne prikaze slik",
    "Default Photos upload and Albums location" : "Privzeto mesto albuma in odložišča",
    "Select the default location for your media" : "Izbor privzetega mesta za predstavne datoteke",
    "Invalid location selected" : "Izbrano je neveljavno mesto",
    "View" : "Poglej",
    "Photos directory" : "Slikovna mapa",
    "_%n photo_::_%n photos_" : ["%n fotografija","%n fotografiji","%n fotografije","%n fotografij"],
    "Manage collaborators for this album" : "Upravljanje sodelujočih za izbran album",
    "Open actions menu" : "Odpri meni dejanj",
    "Edit album details" : "Uredi podrobnosti albuma",
    "Download all files in album" : "Prejmi vse datoteke v albumu",
    "Delete album" : "Izbriši album",
    "Download selected files" : "Prejmi izbrane datoteke",
    "Remove selection from album" : "Odstrani izbor iz albuma",
    "This album does not have any photos or videos yet!" : "V ta album ni še naloženih fotografij in posnetkov!",
    "Add photos to this album" : "Dodaj fotografije v ta album",
    "Manage collaborators" : "Upravljanje s sodelujočimi",
    "Save collaborators for this album." : "Shrani sodelujoče za izbran album",
    "Cover photo for album {albumName}" : "Naslovna fotografija za album {albumName}",
    "There is no album yet!" : "Ni še ustvarjenega albuma!",
    "This person could not be found" : "Osebe ni mogoče najti",
    "Rename person" : "Preimenuj osebo",
    "Merge with different person" : "Združi z obstoječo osebo",
    "Download selected photos" : "Prejmi izbrane datoteke",
    "Favorite" : "Priljubljeno",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Remove person" : "Odstrani osebo",
    "Name of this person" : "Ime osebe",
    "Merge person" : "Združi podatke osebe",
    "This folder does not exist" : "Ta mapa ne obstaja",
    "Loading folders …" : "Poteka nalaganje map …",
    "No photos in here" : "Na tem mestu še ni fotografij",
    "No photos with this tag yet" : "Ni še fotografij, označenih s to oznako.",
    "No tags yet" : "Ni še dodane nobene oznake",
    "Photos with tags will show up here" : "Na tem mestu bodo prikazane fotografije z oznakami.",
    "Popular tags" : "Priljubljene oznake",
    "Add" : "Dodaj",
    "Create a new album" : "Ustvari nov album",
    "Add selection to an album" : "Dodaj izbor v album",
    "Add to album" : "Dodaj album",
    "Delete selection" : "Izbriši izbor",
    "No photos or videos in here" : "Ni še nobenih slik in posnetkov",
    "Failed to fetch collections list." : "Pridobivanje seznama zbirk je spodletelo.",
    "Failed to fetch faces list." : "Pridobivanje seznama obrazov je spodletelo.",
    "All your media" : "Vsi viri",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Albumi v souporabi",
    "Shared album {title}" : "Album {title} v souporabi",
    "Public album {title}" : "Javni album {title}",
    "Tagged photos" : "Označene fotografije",
    "Tagged photo {title}" : "Označena fotografij {title}",
    "{title}'s face" : "{title}: obraz",
    "Failed to delete {fileId}." : "Brisanje polja {fileId} je spodletelo.",
    "Failed to delete {fileName}." : "Brisanje datoteke {fileName} je spodletelo.",
    "Locations" : "Mesta",
    "Search for collaborators" : "Iskanje sodelujočih",
    "Add {collaboratorLabel} to the collaborators list" : "Dodaj {collaboratorLabel} na seznam sodelujočih",
    "No collaborators available" : "Ni navedenih sodelujočih urejevalcev",
    "Failed to fetch album." : "Pridobivanje albuma je spodletelo.",
    "Add photos to the album" : "Dodaj fotografije v album",
    "Shared albums" : "Albumi v souporabi",
    "Failed to create {albumName}." : "Ustvarjanje albuma {albumName} je spodletelo."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-25.0.12.tgz: nextcloud/apps/photos/l10n/sl.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Javna povezava",
    "Photos" : "Fotografije",
    "Your memories under your control" : "Spomini pod vašim nadzorom",
    "All media" : "Vsi viri",
    "Videos" : "Video posnetki",
    "Albums" : "Albumi",
    "Collaborative albums" : "Sodelovalni albumi",
    "People" : "Ljudje",
    "Folders" : "Mape",
    "Favorites" : "Priljubljene",
    "On this day" : "Na današnji dan",
    "Shared with you" : "V souporabi z vami",
    "Tags" : "Oznake",
    "Places" : "Mesta",
    "Map" : "Zemljevid",
    "Photos settings" : "Nastavitve fotografij",
    "Mark selection as favorite" : "Označi izbor kot priljubljene",
    "Add selection to favorites" : "Dodaj izbor med priljubljene",
    "Remove selection from favorites" : "Odstrani izbor iz priljubljenih",
    "Name of the album" : "Ime albuma",
    "Location of the album" : "Mesto albuma",
    "Go back to the previous view." : "Vrni na predhodni pogled.",
    "Back" : "Nazaj",
    "Go to the add collaborators view." : "Skoči na pogled dodajanja sodelujočih.",
    "Add collaborators" : "Dodaj sodelujoče",
    "Save." : "Shrani.",
    "Create the album." : "Ustvari album",
    "Save" : "Shrani",
    "Create album" : "Ustvari album",
    "Back to the new album form." : "Nazaj na pogled obrazca novega albuma.",
    "Add to Album" : "Dodaj v album",
    "Add selection to album {albumName}" : "Dodaj izbor v album {albumName}",
    "Shared by" : "Souporabo omogoča",
    "Create a new album." : "Ustvari nov album.",
    "Create new album" : "Ustvari nov album.",
    "New album" : "Nov album",
    "_%n item_::_%n photos and videos_" : ["%n slika ali videoposnetkek","%n sliki ali videoposnetka","%n slike ali videoposnetki","%n slik in videoposnetkov"],
    "Add people or groups who can edit your album" : "Dodaj osebe in skupine, ki lahko urejajo album",
    "Search people or groups" : "Iskanje oseb in skupin",
    "No recommendations. Start typing." : "Ni priporočil; začnite z vpisovanjem",
    "Group" : "Skupina",
    "Remove {collaboratorLabel} from the collaborators list" : "Odstrani {collaboratorLabel} s seznama sodelujočih",
    "Copy the public link" : "Kopiraj javno povezavo",
    "Public link copied!" : "Povezava je kopirana!",
    "Copy public link" : "Kopiraj javno povezavo",
    "Delete the public link" : "Izbriši javno povezavo",
    "Share via public link" : "V souporabi z javno povezavo",
    "Failed to fetch collaborators list." : "Pridobivanje seznama sodelovanja je spodletelo.",
    "Failed to update album." : "Posodabljanje albuma je spodletelo.",
    "This collection does not exist" : "Zbirka ne obstaja.",
    "An error occurred" : "Prišlo je do napake.",
    "Select image {imageName}" : "Izbor slike {imageName}",
    "The file is in the favorites" : "Datoteka je med priljubljenimi",
    "Open the full size \"{name}\" image" : "Odpri sliko »{name}« v polni velikosti",
    "There are no photos or videos yet!" : "Ni še naloženih fotografij in posnetkov!",
    "Add to {destination}" : "Dodaj k {cilju}",
    "Open the \"{name}\" sub-directory" : "Odpri podmapo »{name}«",
    "Back to {folder}" : "Nazaj v mapo {folder}",
    "Share this folder" : "Omogoči souporabo mape",
    "_{years} year ago_::_{years} years ago_" : ["pred {years} letom","pred {years} letoma","pred {years} leti","pred {years} leti"],
    "Enable squared photos view" : "Omogoči kvadratne prikaze slik",
    "Default Photos upload and Albums location" : "Privzeto mesto albuma in odložišča",
    "Select the default location for your media" : "Izbor privzetega mesta za predstavne datoteke",
    "Invalid location selected" : "Izbrano je neveljavno mesto",
    "View" : "Poglej",
    "Photos directory" : "Slikovna mapa",
    "_%n photo_::_%n photos_" : ["%n fotografija","%n fotografiji","%n fotografije","%n fotografij"],
    "Unselect all" : "Odstrani izbor",
    "Manage collaborators for this album" : "Upravljanje sodelujočih za izbran album",
    "Open actions menu" : "Odpri meni dejanj",
    "Edit album details" : "Uredi podrobnosti albuma",
    "Download all files in album" : "Prejmi vse datoteke v albumu",
    "Delete album" : "Izbriši album",
    "Download selected files" : "Prejmi izbrane datoteke",
    "Remove selection from album" : "Odstrani izbor iz albuma",
    "This album does not have any photos or videos yet!" : "V ta album ni še naloženih fotografij in posnetkov!",
    "Add photos to this album" : "Dodaj fotografije v ta album",
    "Manage collaborators" : "Upravljanje s sodelujočimi",
    "Save collaborators for this album." : "Shrani sodelujoče za izbran album",
    "Cover photo for album {albumName}" : "Naslovna fotografija za album {albumName}",
    "There is no album yet!" : "Ni še ustvarjenega albuma!",
    "This person could not be found" : "Osebe ni mogoče najti",
    "Rename person" : "Preimenuj osebo",
    "Merge with different person" : "Združi z obstoječo osebo",
    "Download selected photos" : "Prejmi izbrane datoteke",
    "Favorite" : "Priljubljeno",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Remove person" : "Odstrani osebo",
    "Name of this person" : "Ime osebe",
    "Merge person" : "Združi podatke osebe",
    "This folder does not exist" : "Ta mapa ne obstaja",
    "Loading folders …" : "Poteka nalaganje map …",
    "No photos in here" : "Na tem mestu še ni fotografij",
    "No photos with this tag yet" : "Ni še fotografij, označenih s to oznako.",
    "No tags yet" : "Ni še dodane nobene oznake",
    "Photos with tags will show up here" : "Na tem mestu bodo prikazane fotografije z oznakami.",
    "Popular tags" : "Priljubljene oznake",
    "Add" : "Dodaj",
    "Add to album" : "Dodaj album",
    "Delete selection" : "Izbriši izbor",
    "No photos or videos in here" : "Ni še nobenih slik in posnetkov",
    "_%n photos_::_%n photos_" : ["%n fotografija","%n fotografiji","%n fotografije","%n fotografij"],
    "Failed to fetch collections list." : "Pridobivanje seznama zbirk je spodletelo.",
    "Failed to fetch faces list." : "Pridobivanje seznama obrazov je spodletelo.",
    "All your media" : "Vsi viri",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Albumi v souporabi",
    "Shared album {title}" : "Album {title} v souporabi",
    "Public album {title}" : "Javni album {title}",
    "Tagged photos" : "Označene fotografije",
    "Tagged photo {title}" : "Označena fotografija {title}",
    "{title}'s face" : "{title}: obraz",
    "Failed to delete {fileId}." : "Brisanje polja {fileId} je spodletelo.",
    "Failed to delete {fileName}." : "Brisanje datoteke {fileName} je spodletelo.",
    "Locations" : "Mesta",
    "Search for collaborators" : "Iskanje sodelujočih",
    "Add {collaboratorLabel} to the collaborators list" : "Dodaj {collaboratorLabel} na seznam sodelujočih",
    "No collaborators available" : "Ni navedenih sodelujočih urejevalcev",
    "Failed to fetch album." : "Pridobivanje albuma je spodletelo.",
    "Add photos to the album" : "Dodaj fotografije v album",
    "Shared albums" : "Albumi v souporabi",
    "Create a new album" : "Ustvari nov album",
    "Add selection to an album" : "Dodaj izbor v album",
    "Failed to create {albumName}." : "Ustvarjanje albuma {albumName} je spodletelo."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
